Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(125)

Unified Diff: runtime/vm/raw_object.h

Issue 2891053003: Add support for converted closures with explicit contexts to VM (Closed)
Patch Set: Temporarily disable Run step in closures test suite Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/object.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/raw_object.h
diff --git a/runtime/vm/raw_object.h b/runtime/vm/raw_object.h
index b23014cf1d2fb32296db2a661eac0e69ee0be88b..b9d77672ac1d070ffc46b2ecffaecb481ccdec9a 100644
--- a/runtime/vm/raw_object.h
+++ b/runtime/vm/raw_object.h
@@ -183,10 +183,12 @@ enum ClassId {
kByteBufferCid,
// The following entries do not describe a predefined class, but instead
// are class indexes for pre-allocated instances (Null, dynamic and Void).
kNullCid,
kDynamicCid,
kVoidCid,
+ kVectorCid,
kNumPredefinedCids,
};
@@ -829,6 +831,7 @@ class RawFunction : public RawObject {
enum Kind {
kRegularFunction,
kClosureFunction,
+ kConvertedClosureFunction,
kSignatureFunction, // represents a signature only without actual code.
kGetterFunction, // represents getter functions e.g: get foo() { .. }.
kSetterFunction, // represents setter functions e.g: set foo(..) { .. }.
@@ -183,10 +183,12 @@ enum ClassId {
kByteBufferCid,
// The following entries do not describe a predefined class, but instead
- // are class indexes for pre-allocated instances (Null, dynamic and Void).
+ // are class indexes for pre-allocated instances (Null, dynamic, Void and
+ // Vector).
kNullCid,
kDynamicCid,
« no previous file with comments | « runtime/vm/object.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698